@@ -128,8 +128,10 @@ int camera_last_ls(void)
 		dump_filename(dirlist[j]);
 	}
 
-	printf("last ls pathname was: %s\n", lastpath);
-	printf("lastls successful\n");
+        if (opt_debug) {
+          printf("last ls pathname was: %s\n", lastpath);
+          printf("lastls successful\n");
+        }
 	return 0;
 }
 
@@ -158,7 +160,9 @@ int camera_get_last_ls(int which)
 		camera_get_image(aux, NULL);
 		printf("\n");
 	}
-	printf("getlastls successful\n");
+        if (opt_debug) {
+          printf("getlastls successful\n");
+        }
 	return 0;
 }
 
@@ -186,10 +190,10 @@ int offset_from_GMT (void) {
   if (gettimeofday(&tv[0], NULL))
     err(1, "gettimeofday");
 
-  tm1 = localtime (&(tv[0].tv_sec));
+  tm1 = localtime ((const time_t *) &(tv[0].tv_sec));
   tm1_copy = *tm1; /* struct copy */
 
-  tm2 = gmtime (&(tv[0].tv_sec));
+  tm2 = gmtime ((const time_t *) &(tv[0].tv_sec));
 
   t1 = mktime (&tm1_copy);
   t2 = mktime (tm2);
@@ -226,6 +230,10 @@ int camera_get_list(char *pathname)
 		pathname = arg;
 	}
 
+        /* Skip "*.ctg" files */
+        if ((pkt = strstr (pathname, ".CTG"))) {
+          return 0;
+        }
 	switch(mode) {
 	case SERIAL_MODE:
 		aux[0] = DL_NO_RECURSION;
@@ -424,7 +432,7 @@ int camera_get_image(char *pathname, char *destfile)
 		if (!timestamp)
 			timestamp = 1;
 		printf("\nDownloaded in %ld seconds, %ld bytes/s\n",
-			timestamp, len/timestamp);
+                       (long)timestamp, (long) len/timestamp);
 
 		imagedate = get_date_for_image (orig_pathname);
 		
@@ -532,7 +540,7 @@ int camera_get_thumb(char *pathname, char *destfile)
 			timestamp = 1;
 		printf("Downloaded in %ld seconds,"
 			" %ld bytes/s\n",
-			timestamp, len/timestamp);
+                       (long)timestamp, (long)len/timestamp);
 		free(image);
 	}
 	return 0;
