@@ -36,6 +36,7 @@ struct canonfile *dirlist[1024];
 int dirlist_size = 0;
 char lastpath[1024] = {'\0'};
 char cameraid[1024];
+char dcimpath[1024] = { "D:\\DCIM" };
 char firmware[8];
 int mode = SERIAL_MODE; /* this is the default mode */
 int use_lowers = 0;     /* write out files with upper case chars by default */
@@ -50,7 +51,8 @@ int main(int argc, char **argv)
 	char *command_argv[COMMANDARGS_MAX+1] = { NULL };
 	int command_argc;
 	int c;
-	int cli_getall = 0, cli_listall = 0, cli_deleteall = 0, cli_test = 0;
+	int cli_getallnew = 0, cli_getall = 0, cli_listall = 0;
+        int cli_deleteall = 0, cli_test = 0;
 	
 	signal(SIGTERM, signal_trap);
 	signal(SIGINT, signal_trap);
@@ -64,7 +66,7 @@ int main(int argc, char **argv)
 	*/
 	GMT_offset = offset_from_GMT();
 	
-        while ((c = getopt(argc, argv, "d:DulgEhUas:L")) != EOF) {
+        while ((c = getopt(argc, argv, "d:DulgEhUas:Ln")) != EOF) {
 		switch(c) {
 		case 'D':
 			opt_debug = 1;
@@ -85,6 +87,9 @@ int main(int argc, char **argv)
 		case 'g':
 			cli_getall = 1;
 			break;
+		case 'n':
+			cli_getallnew = 1;
+			break;
 		case 'l':
 			cli_listall = 1;
 			break;
@@ -125,7 +130,10 @@ int main(int argc, char **argv)
 		do_cli_listall();
 		safe_exit(0);
 	} else if (cli_getall) {
-		do_cli_getall();
+		do_cli_getall(WHICH_ALL);
+		safe_exit(0);
+	} else if (cli_getallnew) {
+		do_cli_getall(WHICH_NEW);
 		safe_exit(0);
 	} else if (cli_deleteall) {
 		do_cli_deleteall();
@@ -298,6 +306,7 @@ int main(int argc, char **argv)
 			else
 				t = USB_get_date();
 #endif
+                        t += GMT_offset;
 			printf("Camera date: %s", ctime(&t));
 		} else if (!strcmp(cmd, "speed")) {
 			int old_speed = serial_speed;
@@ -591,13 +600,13 @@ int byteswap32(int val)
 	return val;
 }
 
-void do_cli_getall(void)
+void do_cli_getall(int which)
 {
 	int j, c;
 	char *directory[1024];
 
-	if (camera_get_list("D:\\DCIM") == -1) {
-		printf("Error listing D:\\DCIM\n");
+	if (camera_get_list(dcimpath) == -1) {
+		printf("Error listing %s\n", dcimpath);
 		exit(1);
 	}
 
@@ -609,7 +618,7 @@ void do_cli_getall(void)
 	c = 0;
 	for (j = 0; j < dirlist_size; j++) {
 		if (!(dirlist[j]->type & ATTR_ITEMS))
-				continue;
+                  continue;
 		directory[c] = malloc(strlen(dirlist[j]->name)+1);
 		if (!directory[c]) {
 			perror("malloc");
@@ -627,7 +636,9 @@ void do_cli_getall(void)
 			printf("Error listing %s\n", directory[c]);
 			exit(1);
 		}
-		if (camera_get_last_ls(WHICH_ALL) == -1) {
+		if (dirlist_size == 0) {
+                    printf("skipping empty directory\n");
+		} else if (camera_get_last_ls(which) == -1) {
 			printf("camera_get_last_ls error\n");
 			exit(1);
 		}
@@ -644,8 +655,8 @@ void do_cli_listall(void)
 	int j, c;
 	char *directory[1024];
 
-	if (camera_get_list("D:\\DCIM") == -1) {
-		printf("Error listing D:\\DCIM\n");
+	if (camera_get_list(dcimpath) == -1) {
+		printf("Error listing %s\n", dcimpath);
 		exit(1);
 	}
 
@@ -693,8 +704,8 @@ void do_cli_deleteall(void)
 	if (getchar() != 'y')
 		exit(0);
 
-	if (camera_get_list("D:\\DCIM") == -1) {
-		printf("Error listing D:\\DCIM\n");
+	if (camera_get_list(dcimpath) == -1) {
+		printf("Error listing %s\n", dcimpath);
 		exit(1);
 	}
 
@@ -754,23 +765,32 @@ void do_cli_deleteall(void)
 
 void show_usage(void)
 {
-	printf(
-"s10sh -- Canon PowerShot S10/S20/S100 digital camera software\n"
-"Version %s\n\n"
-"usage: s10sh -[DuglELh] -d <serialdevice>\n\n"
-"  -D                    enable debug mode\n"
+  printf(
+         "s10sh -- Canon PowerShot S10/S20/S100 digital camera software\n"
+         "Version %s\n\n"
+         "usage: s10sh -[DugnlELh] -d <serialdevice>\n\n"
+         "  -D                    enable debug mode\n"
 #if __FreeBSD__
-"  -d <serialdevice>     set the serial device, default /dev/cuaa0\n"
+         "  -d <serialdevice>     set the serial device, default /dev/cuaa0\n"
 #else
-"  -d <serialdevice>     set the serial device, default /dev/ttyS0\n"
+         "  -d <serialdevice>     set the serial device, default /dev/ttyS0\n"
 #endif
-"  -a                    enable A50/Pro70 compatibility mode\n"
-"  -s <serialspeed>      set the serial speed (9600 19200 38400 57600 115200)\n"
-"  -u                    USB mode, default is serial mode\n"
-"  -g                    non-interactive mode, get all images\n"
-"  -l                    non-interactive mode, list all images\n"
-"  -E                    non-interactive mode, delete all images\n"
-"  -L                    write files using all lower-case characters\n"
-"  -h                    show this help screen\n", VERSION
-	);
+         "  -a                    enable A50/Pro70 compatibility mode\n"
+         "  -s <serialspeed>      set the serial speed (9600 19200 38400 57600 115200)\n"
+         "  -u                    USB mode, default is serial mode\n"
+         "  -g                    non-interactive mode, get all images\n"
+         "  -n                    non-interactive mode, get all new images\n"
+         "  -l                    non-interactive mode, list all images\n"
+         "  -E                    non-interactive mode, delete all images\n"
+         "  -L                    write files using all lower-case characters\n"
+         "  -h                    show this help screen\n", VERSION
+         );
+}
+
+void setdcimpath(const char *path)
+{
+  snprintf(dcimpath, sizeof(dcimpath), "%s", path);
+  if (opt_debug) {
+    printf ("dcimpath set to '%s'\n", dcimpath);
+  }
 }
