@@ -7,13 +7,13 @@ fi
 
 mkdir s10sh-${1} || exit 1
 cp * s10sh-${1}
-cp -a libusb-0.1.3b s10sh-${1}
+cp -a libusb-0.1.7 s10sh-${1}
 cd s10sh-${1} || exit 1
 rm -f *.JPG
 rm -f ./s10sh_REMOVE_ME
 make distclean
 rm -f libusb
-ln -s libusb-0.1.3b libusb
+ln -s libusb-0.1.7 libusb
 cd libusb
 make distclean
 cd ../../
